package com.daim.flutter_apm

import androidx.annotation.NonNull
import com.moonmiles.apm.sdk.APMPrivate
import com.moonmiles.apmservices.sdk.APMServicesPrivate
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

/** ApmModule */
class ApmModule : FlutterPlugin, MethodCallHandler {
    private lateinit var channel: MethodChannel

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        channel = MethodChannel(flutterPluginBinding.binaryMessenger, "apm_module")
        channel.setMethodCallHandler(this)
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        if (call.method == "initAppWithAppID") {
            initAppWithPartnerID(call.arguments as HashMap<*, *>, result)
        } else if (call.method == "refreshSDK") {
            refreshSDK(call.arguments as Boolean, result)
        } else if (call.method == "setBaseUrl") {
            setBaseUrl(call.arguments as String, result)
        } else {
            result.notImplemented()
        }
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        channel.setMethodCallHandler(null)
    }

    private fun initAppWithPartnerID(arguments: HashMap<*, *>, result: MethodChannel.Result) {
        val partnerId = arguments["partnerId"] as String?
        val partnerSecret = arguments["partnerSecret"] as String?
        val appId = arguments["appId"] as String?
        APMPrivate.sharedInstancePrivate().initApp(partnerId, partnerSecret, appId)
        result.success(null)
    }

    private fun refreshSDK(force: Boolean, result: MethodChannel.Result) {
        APMServicesPrivate.sharedInstancePrivate().refreshSDK(force)
        result.success(null)
    }

    private fun setBaseUrl(baseUrl: String, result: MethodChannel.Result) {
        APMPrivate.sharedInstancePrivate().baseUrl = baseUrl
        result.success(null)
    }
}
