import Flutter
import UIKit
import APM

public class ApmModule: NSObject, FlutterPlugin {
    public static func register(with registrar: FlutterPluginRegistrar) {
        let instance = ApmModule()
        let channel = FlutterMethodChannel(name: "apm_module", binaryMessenger: registrar.messenger())
        registrar.addMethodCallDelegate(instance, channel: channel)
    }

    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        if(call.method.elementsEqual("initAppWithAppID")) {
            initAppWithPartnerID(arguments: call.arguments as! [String: AnyHashable], result: result)
        }
        else if(call.method.elementsEqual("refreshSDK")) {
            refreshSDK(force: call.arguments as! Bool, result: result)
        }
        else if(call.method.elementsEqual("setBaseUrl")) {
            setBaseUrl(baseUrl: call.arguments as! String, result: result)
        }
        else {
            result(FlutterMethodNotImplemented)
        }
    }

    private func getPlatformVersion(result: FlutterResult) {
        result("iOS " + UIDevice.current.systemVersion)
    }

    private func initAppWithPartnerID(arguments: [String: AnyHashable], result: FlutterResult) {
        let partnerId = arguments["partnerId"] as! String
        let partnerSecret = arguments["partnerSecret"] as! String
        let appId = arguments["appId"] as! String
        APM.sharedInstance()!.initApp(withPartnerID: partnerId, withPartnerSecret: partnerSecret, withAppId: appId)
        result(nil)
    }

    private func refreshSDK(force: Bool, result: FlutterResult) {
        APMServices.sharedInstance()!.refreshSDK(force)
        result(nil)
    }

    private func setBaseUrl(baseUrl: String, result: FlutterResult) {
        APMServices.sharedInstance()!.baseUrl = baseUrl
        result(nil)
    }
}
